@@ -19,7 +19,7 @@ package PostScript::File::Metrics::Loader;
 
 use 5.008;
 our $VERSION = '2.20';          ## no critic
-# This file is part of PostScript-File 2.20 (February 11, 2012)
+# This file is part of PostScript-File 2.22 (May 9, 2015)
 
 use strict;
 use warnings;
@@ -259,8 +259,8 @@ PostScript::File::Metrics::Loader - Load metrics for PostScript fonts using Font
 =head1 VERSION
 
 This document describes version 2.20 of
-PostScript::File::Metrics::Loader, released February 11, 2012
-as part of PostScript-File version 2.20.
+PostScript::File::Metrics::Loader, released May 9, 2015
+as part of PostScript-File version 2.22.
 
 =head1 DESCRIPTION
 
@@ -388,11 +388,11 @@ or through the web interface at
 L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-File >>.
 
 You can follow or contribute to PostScript-File's development at
-L<< http://github.com/madsen/postscript-file >>.
+L<< https://github.com/madsen/postscript-file >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Christopher J. Madsen.
+This software is copyright (c) 2015 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
